<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Ultravel
 * @since Ultravel 1.0.0
 * @return array An array of default values
 */

function ultravel_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$ultravel_default_options = array(
		// Color Options
		'header_title_color'			=> '#000',
		'header_tagline_color'			=> '#000',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#00afe9',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',

		//body typography
		'body_font_family'			=> 'Muli',
		'body_font_weight'			=> 300,
		'body_font_size'			=> 16,
		'body_font_style'			=> 'normal',
		'body_text_transform'		=> 'none',

		//h1 typography
		'heading_h1_font_family'		=> 'Raleway',
		'heading_h1_font_weight'		=> 300,
		'heading_h1_text_transform'		=> 'none',
		'heading_h1_font_style'			=> 'normal',

		//h2 typography
		'heading_h2_font_family'		=> 'Raleway',
		'heading_h2_font_weight'		=> 700,
		'heading_h2_text_transform'		=> 'none',
		'heading_h2_font_style'			=> 'normal',

		//h3 typography
		'heading_h3_font_family'		=> 'Raleway',
		'heading_h3_font_weight'		=> 700,
		'heading_h3_text_transform'		=> 'none',
		'heading_h3_font_style'			=> 'normal',

		//h4 typography
		'heading_h4_font_family'		=> 'Raleway',
		'heading_h4_font_weight'		=> 700,
		'heading_h4_text_transform'		=> 'none',
		'heading_h4_font_style'			=> 'normal',

		//h5 typography
		'heading_h5_font_family'		=> 'Raleway',
		'heading_h5_font_weight'		=> 700,
		'heading_h5_text_transform'		=> 'none',
		'heading_h5_font_style'			=> 'normal',

		//h6 typography
		'heading_h6_font_family'		=> 'Raleway',
		'heading_h6_font_weight'		=> 700,
		'heading_h6_text_transform'		=> 'none',
		'heading_h6_font_style'			=> 'normal',

		//p typography
		'heading_p_font_family'			=> 'Muli',
		'heading_p_font_weight'			=> 400,
		'heading_p_text_transform'		=> 'none',
		'heading_p_font_style'			=> 'normal',

		//button
		'button_background_color'		=> '#e5f8fc',
		'button_text_color'		=> '#00afe9',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'social_nav_enable'				=> true,
		'search_nav_enable'				=> true,
		'cart_nav_enable'				=> false,


		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'ultravel' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'ultravel' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'ultravel' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'default_sortable' 				=> 'hero_slider,about,activities,testimonial,popular_posts,subscribe_now',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'ultravel' ),
		'hide_btn' 						=> false,
		'hide_category'					=> false,
		'hide_content'					=> false,
		'hide_image'					=> false,
		'hide_date'					    => false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */
		// new 
		// Hero Slider
		'hero_slider_section_enable'		=> false,
		'hero_slider_title'				    => esc_html__( 'Lifestyle. Explore. Travel.', 'ultravel' ),
		'hero_slider_autoplay'				=> false,
		'hero_slider_content_type'			=> 'page',
		'hero_slider_count'					=> 3,

		// about
		'about_section_enable'			=> false,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'Explore all corners of the world with us.', 'ultravel' ),
		'about_sub_title'				=> esc_html__( 'About Us', 'ultravel' ),
		'about_description'				=> esc_html__( 'When on the road, this isn’t always possible, with time, space and convenience restrictions often conspiring against your ideal lifestyle & so on other things. Fall in love with a problem.', 'ultravel' ),
		'about_btn_title'				=> esc_html__( 'About Ultravel', 'ultravel' ),

		//service 
		'service_section_enable'		=> (bool) false,
		'service_content_type'			=> 'post',
		'service_count'					=> 3,
		'service_excerpt_length'		=> 20,

		// activities
		'activities_sub_title'		    => esc_html__( 'Travel by Activities', 'ultravel' ),
		'activities_title'				=> esc_html__( 'More than 25+ tour types', 'ultravel' ),
		'activities_section_enable'		=> false,
		'activities_content_type'		=> 'category',
		'activities_count'				=> 4,


		// testimonial
		'testimonial_section_enable'	=> false,
		'testimonial_title'		=> esc_html__( 'Read what our clients says about us.', 'ultravel' ),
		'testimonial_sub_title'		=> esc_html__( 'Testimonials', 'ultravel' ),
		'testimonial_content'		=> esc_html__( 'When on the road, this isn’t always possible, with time, space and convenience restrictions often conspiring against your ideal lifestyle & so on other things.', 'ultravel' ),
		'testimonial_auto_play'			=> false,
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 4,


		// popular posts
		'popular_posts_section_enable'			=> false,
		'popular_posts_content_type'			=> 'category',
		'popular_posts_title'					=> esc_html__( 'Our recent articles', 'ultravel' ),
		'popular_posts_sub_title'				=> esc_html__( 'Latest news & blogs', 'ultravel' ),

		// counter
		'counter_section_enable'		=> (bool) false,
		'counter_count'					=> 4,
		'counter_column'				=> 'col-4',

		// subscribe_now
		'subscribe_now_section_enable'	=> false,
		'subscribe_now_sub_title'		=> esc_html__( 'Everyone wants the outcome, but in order to be motivated to work towards it, day in and day out, you have to learn to get some rest.', 'ultravel' ),
		'subscribe_now_title'			=> esc_html__( 'Subscribe Newsletter', 'ultravel' ),
		'subscribe_now_btn'			    => esc_html__( 'Send', 'ultravel' ),


	);

	$output = apply_filters( 'ultravel_default_theme_options', $ultravel_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}