<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Ultravel
 * @since Ultravel 1.0.0
 */
if ( ! function_exists( 'ultravel_add_popular_posts_section' ) ) :
    /**
    * Add blog section
    *
    *@since Ultravel 1.0.0
    */
    function ultravel_add_popular_posts_section() {
    	$options = ultravel_get_theme_options();
        // Check if blog is enabled on frontpage
        $popular_posts_enable = apply_filters( 'ultravel_section_status', true, 'popular_posts_section_enable' );

        if ( true !== $popular_posts_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'ultravel_filter_popular_posts_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        ultravel_render_popular_posts_section( $section_details );
    }
endif;

if ( ! function_exists( 'ultravel_get_popular_posts_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Ultravel 1.0.0
    * @param array $input blog section details.
    */
    function ultravel_get_popular_posts_section_details( $input ) {
        $options = ultravel_get_theme_options();

        // Content type.
        $popular_posts_content_type  = $options['popular_posts_content_type'];
        $popular_posts_count = 4;
        
        $content = array();
        switch ( $popular_posts_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $popular_posts_count; $i++ ) {
                    if ( ! empty( $options['popular_posts_content_page_' . $i] ) )
                        $page_ids[] = $options['popular_posts_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_posts_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $popular_posts_count; $i++ ) {
                    if ( ! empty( $options['popular_posts_content_post_' . $i] ) )
                        $post_ids[] = $options['popular_posts_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $popular_posts_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['popular_posts_content_category'] ) ? $options['popular_posts_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $popular_posts_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = ultravel_trim_content( 20 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg'; 

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'ultravel_filter_popular_posts_section_details', 'ultravel_get_popular_posts_section_details' );


if ( ! function_exists( 'ultravel_render_popular_posts_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Ultravel 1.0.0
   *
   */
   function ultravel_render_popular_posts_section( $content_details = array() ) {
        $options = ultravel_get_theme_options();
        $popular_posts_content_type  = $options['popular_posts_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="ultravel_popular_posts_section" class="relative page-section same-background">
            <div class="wrapper">
                <?php if ( is_customize_preview()):
                    ultravel_section_tooltip( 'ultravel_popular_posts_section' );
                endif; ?>
                <div class="section-header">
                    <?php if ( ! empty( $options['popular_posts_sub_title'] ) ) : ?>
                        <p class="section-subtitle"><?php echo esc_html( $options['popular_posts_sub_title'] ); ?></p>
                    <?php endif; ?>
                    <?php if ( ! empty( $options['popular_posts_title'] ) ) : ?>
                        <h2 class="section-title"><?php echo esc_html( $options['popular_posts_title'] ); ?></h2>
                    <?php endif; ?>
                </div><!-- .section-header -->

                <div class="section-content clear">
                    <?php foreach ( $content_details as $content ) : ?>
                        <article class="has-post-thumbnail">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-meta">
                                    <?php ultravel_posted_on( $content['id'] ) ; ?>   
                                </div><!-- .entry-meta -->   

                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->
                                
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- .section-content -->
            </div>
        </div><!-- #magazine-popular-posts -->
    <?php }
endif;