<?php
/**
 * Testimonial section
 *
 * This is the template for the content of testimonial section
 *
 * @package Theme Palace
 * @subpackage Ultravel
 * @since Ultravel 1.0.0
 */
if ( ! function_exists( 'ultravel_add_testimonial_section' ) ) :
    /**
    * Add testimonial section
    *
    *@since Ultravel 1.0.0
    */
    function ultravel_add_testimonial_section() {
        $options = ultravel_get_theme_options();
        // Check if testimonial is enabled on frontpage
        $testimonial_enable = apply_filters( 'ultravel_section_status', true, 'testimonial_section_enable' );

        if ( true !== $testimonial_enable ) {
            return false;
        }
        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'ultravel_filter_testimonial_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render testimonial section now.
        ultravel_render_testimonial_section( $section_details );
    }
endif;

if ( ! function_exists( 'ultravel_get_testimonial_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since Ultravel 1.0.0
    * @param array $input testimonial section details.
    */
    function ultravel_get_testimonial_section_details( $input ) {
        $options = ultravel_get_theme_options();

        // Content type.
        $testimonial_content_type  = $options['testimonial_content_type'];
        $testimonial_count = ! empty( $options['testimonial_count'] ) ? $options['testimonial_count'] : 4;
        $content = array();
        switch ( $testimonial_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_page_' . $i] ) ) :
                        $page_ids[] = $options['testimonial_content_page_' . $i];
                        $author[] = ! empty( $options['testimonial_author_' . $i] ) ? $options['testimonial_author_' . $i] : '';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $author = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_post_' . $i] ) ) :
                        $post_ids[] = $options['testimonial_content_post_' . $i];
                        $author[] = ! empty( $options['testimonial_author_' . $i] ) ? $options['testimonial_author_' . $i] : '';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['testimonial_content_category'] ) ? $options['testimonial_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $testimonial_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'custom':
                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    $custom['id']           = $i;
                    $custom['title']        = ! empty( $options['testimonial_title_' . $i] ) ? $options['testimonial_title_' . $i] : '';
                    $custom['excerpt']      = ! empty( $options['testimonial_description_' . $i] ) ? $options['testimonial_description_' . $i] : '';
                    $custom['image']        = ! empty( $options['testimonial_image_' . $i] ) ? $options['testimonial_image_' . $i] : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                    $custom['url']          = ! empty( $options['testimonial_link_' . $i] ) ? $options['testimonial_link_' . $i] : '';
                    $custom['position']     = ! empty( $options['testimonial_author_' . $i] ) ? $options['testimonial_author_' . $i] : '';


                    // Push to the main array.
                    array_push( $content, $custom );
                }
            break;
            
            default:
            break;
        }

        if ( 'custom' !== $testimonial_content_type ) {
            // Run The Loop.
            $query = new WP_Query( $args );
            $i = 0;
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['author']    = ( 'category' !== $testimonial_content_type && ! empty( $author[$i] ) ) ? $author[$i] : '';
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = ultravel_trim_content( 25 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();
        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// testimonial section content details.
add_filter( 'ultravel_filter_testimonial_section_details', 'ultravel_get_testimonial_section_details' );


if ( ! function_exists( 'ultravel_render_testimonial_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string testimonial content
   * @since Ultravel 1.0.0
   *
   */
   function ultravel_render_testimonial_section( $content_details = array() ) {
        $options = ultravel_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="ultravel_testimonial_section" class="page-section same-background">
            <?php if ( is_customize_preview()):
                ultravel_section_tooltip( 'ultravel_testimonial_section' );
            endif; ?>
            <div class="wrapper">
                <div class="section-header-wrapper">
                    <div class="section-header">
                        <p class="section-subtitle"><?php echo esc_html( $options['testimonial_sub_title'] ); ?></p>
                        <h2 class="section-title"><?php echo esc_html( $options['testimonial_title'] ); ?></h2>
                    </div><!-- .section-header -->

                    <div class="section-content">
                        <p><?php echo esc_html( $options['testimonial_content'] ); ?></p>
                    </div>
                </div>

                <div class="testimonial-content">
                    <div class="testimonial-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": false, "speed": 1000, "dots": false, "arrows":false, "autoplay": <?php echo $options['testimonial_auto_play'] ? 'true' : 'false'; ?>, "draggable": true, "fade": false }'>

                        <?php $i=1; foreach ( $content_details as $content ) : ?>
                            <article>
                                <div class="featured-image clear">
                                    <div class="image-wrapper" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    </div>

                                    <div class="testimonial-wrapper">
                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div>
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                            <?php if ( !empty( $options['testimonial_position_'.$i] ) ): ?>
                                                <p class="position"><?php echo esc_html( $options['testimonial_position_'.$i] ); ?></p>
                                            <?php endif ?>                                            
                                        </header>
                                    </div>
                                </div><!-- .featured-image -->
                            </article>
                        <?php endforeach; ?>
                        
                    </div>
                </div>
            </div>
        </div>    
    <?php }
endif;
